@@ -48,9 +48,7 @@ func helpText(perm string) struct{ readHelp, writeHelp string } {
 
 func hidden(perm string) bool {
 	var hiddenTypes = map[string]struct{}{
-		"functions":    {},
-		"remotes":      {},
-		"replications": {},
+		"functions": {},
 	}
 	_, ok := hiddenTypes[perm]
 	return ok
@@ -122,6 +120,9 @@ func newCreateCommand() cli.Command {
 		Flags:  flags,
 		Before: middleware.WithBeforeFns(withCli(), withApi(true), middleware.NoArgs),
 		Action: func(ctx *cli.Context) error {
+			if err := checkOrgFlags(&params.OrgParams); err != nil {
+				return err
+			}
 			params.WriteBucketIds = ctx.StringSlice("write-bucket")
 			params.ReadBucketIds = ctx.StringSlice("read-bucket")
 
@@ -191,6 +192,9 @@ func newListCommand() cli.Command {
 		Flags:   flags,
 		Before:  middleware.WithBeforeFns(withCli(), withApi(true), middleware.NoArgs),
 		Action: func(ctx *cli.Context) error {
+			if err := checkOrgFlags(&params.OrgParams); err != nil {
+				return err
+			}
 			api := getAPI(ctx)
 			client := auth.Client{
 				CLI:               getCLI(ctx),
